@@ -1,4 +1,5 @@
-package My::Fuz;
+package #hide from CPAN
+        My::Fuz;
 use strict;
 use warnings;
 sub fuz {"My::Fuz::fuz"};
